
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import tensor_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__pb2
from ....tensorflow.core.framework import tensor_shape_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2
from ....tensorflow.core.framework import types_pb2 as tensorflow_dot_core_dot_framework_dot_types__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/snapshot.proto', package='tensorflow.data.experimental', syntax='proto3', serialized_options=b'ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto', create_key=_descriptor._internal_create_key, serialized_pb=b'\n\'tensorflow/core/protobuf/snapshot.proto\x12\x1ctensorflow.data.experimental\x1a&tensorflow/core/framework/tensor.proto\x1a,tensorflow/core/framework/tensor_shape.proto\x1a%tensorflow/core/framework/types.proto"9\n\x0eSnapshotRecord\x12\'\n\x06tensor\x18\x01 \x03(\x0b2\x17.tensorflow.TensorProto"\xb8\x01\n\x16SnapshotMetadataRecord\x12\x12\n\ngraph_hash\x18\x01 \x01(\t\x12\x0e\n\x06run_id\x18\x02 \x01(\t\x12\x1a\n\x12creation_timestamp\x18\x03 \x01(\x03\x12\x0f\n\x07version\x18\x04 \x01(\x03\x12#\n\x05dtype\x18\x05 \x03(\x0e2\x14.tensorflow.DataType\x12\x14\n\x0cnum_elements\x18\x06 \x01(\x03\x12\x12\n\tfinalized\x18\xe8\x07 \x01(\x08"_\n\x0eTensorMetadata\x122\n\x0ctensor_shape\x18\x02 \x01(\x0b2\x1c.tensorflow.TensorShapeProto\x12\x19\n\x11tensor_size_bytes\x18\x03 \x01(\x03"_\n\x16SnapshotTensorMetadata\x12E\n\x0ftensor_metadata\x18\x01 \x03(\x0b2,.tensorflow.data.experimental.TensorMetadataBWZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_protob\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_tensor__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_types__pb2.DESCRIPTOR])
_SNAPSHOTRECORD = _descriptor.Descriptor(name='SnapshotRecord', full_name='tensorflow.data.experimental.SnapshotRecord', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='tensor', full_name='tensorflow.data.experimental.SnapshotRecord.tensor', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=198, serialized_end=255)
_SNAPSHOTMETADATARECORD = _descriptor.Descriptor(name='SnapshotMetadataRecord', full_name='tensorflow.data.experimental.SnapshotMetadataRecord', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='graph_hash', full_name='tensorflow.data.experimental.SnapshotMetadataRecord.graph_hash', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='run_id', full_name='tensorflow.data.experimental.SnapshotMetadataRecord.run_id', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='creation_timestamp', full_name='tensorflow.data.experimental.SnapshotMetadataRecord.creation_timestamp', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='version', full_name='tensorflow.data.experimental.SnapshotMetadataRecord.version', index=3, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dtype', full_name='tensorflow.data.experimental.SnapshotMetadataRecord.dtype', index=4, number=5, type=14, cpp_type=8, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_elements', full_name='tensorflow.data.experimental.SnapshotMetadataRecord.num_elements', index=5, number=6, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='finalized', full_name='tensorflow.data.experimental.SnapshotMetadataRecord.finalized', index=6, number=1000, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=258, serialized_end=442)
_TENSORMETADATA = _descriptor.Descriptor(name='TensorMetadata', full_name='tensorflow.data.experimental.TensorMetadata', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='tensor_shape', full_name='tensorflow.data.experimental.TensorMetadata.tensor_shape', index=0, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensor_size_bytes', full_name='tensorflow.data.experimental.TensorMetadata.tensor_size_bytes', index=1, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=444, serialized_end=539)
_SNAPSHOTTENSORMETADATA = _descriptor.Descriptor(name='SnapshotTensorMetadata', full_name='tensorflow.data.experimental.SnapshotTensorMetadata', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='tensor_metadata', full_name='tensorflow.data.experimental.SnapshotTensorMetadata.tensor_metadata', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=541, serialized_end=636)
_SNAPSHOTRECORD.fields_by_name['tensor'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__pb2._TENSORPROTO
_SNAPSHOTMETADATARECORD.fields_by_name['dtype'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_TENSORMETADATA.fields_by_name['tensor_shape'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2._TENSORSHAPEPROTO
_SNAPSHOTTENSORMETADATA.fields_by_name['tensor_metadata'].message_type = _TENSORMETADATA
DESCRIPTOR.message_types_by_name['SnapshotRecord'] = _SNAPSHOTRECORD
DESCRIPTOR.message_types_by_name['SnapshotMetadataRecord'] = _SNAPSHOTMETADATARECORD
DESCRIPTOR.message_types_by_name['TensorMetadata'] = _TENSORMETADATA
DESCRIPTOR.message_types_by_name['SnapshotTensorMetadata'] = _SNAPSHOTTENSORMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
SnapshotRecord = _reflection.GeneratedProtocolMessageType('SnapshotRecord', (_message.Message,), {'DESCRIPTOR': _SNAPSHOTRECORD, '__module__': 'tensorflow.core.protobuf.snapshot_pb2'})
_sym_db.RegisterMessage(SnapshotRecord)
SnapshotMetadataRecord = _reflection.GeneratedProtocolMessageType('SnapshotMetadataRecord', (_message.Message,), {'DESCRIPTOR': _SNAPSHOTMETADATARECORD, '__module__': 'tensorflow.core.protobuf.snapshot_pb2'})
_sym_db.RegisterMessage(SnapshotMetadataRecord)
TensorMetadata = _reflection.GeneratedProtocolMessageType('TensorMetadata', (_message.Message,), {'DESCRIPTOR': _TENSORMETADATA, '__module__': 'tensorflow.core.protobuf.snapshot_pb2'})
_sym_db.RegisterMessage(TensorMetadata)
SnapshotTensorMetadata = _reflection.GeneratedProtocolMessageType('SnapshotTensorMetadata', (_message.Message,), {'DESCRIPTOR': _SNAPSHOTTENSORMETADATA, '__module__': 'tensorflow.core.protobuf.snapshot_pb2'})
_sym_db.RegisterMessage(SnapshotTensorMetadata)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import tensor_description_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__description__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/framework/log_memory.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x18org.tensorflow.frameworkB\x0fLogMemoryProtosP\x01ZQgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/log_memory_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n*tensorflow/core/framework/log_memory.proto\x12\ntensorflow\x1a2tensorflow/core/framework/tensor_description.proto"0\n\rMemoryLogStep\x12\x0f\n\x07step_id\x18\x01 \x01(\x03\x12\x0e\n\x06handle\x18\x02 \x01(\t"p\n\x19MemoryLogTensorAllocation\x12\x0f\n\x07step_id\x18\x01 \x01(\x03\x12\x13\n\x0bkernel_name\x18\x02 \x01(\t\x12-\n\x06tensor\x18\x03 \x01(\x0b2\x1d.tensorflow.TensorDescription"L\n\x1bMemoryLogTensorDeallocation\x12\x15\n\rallocation_id\x18\x01 \x01(\x03\x12\x16\n\x0eallocator_name\x18\x02 \x01(\t"{\n\x15MemoryLogTensorOutput\x12\x0f\n\x07step_id\x18\x01 \x01(\x03\x12\x13\n\x0bkernel_name\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\x05\x12-\n\x06tensor\x18\x04 \x01(\x0b2\x1d.tensorflow.TensorDescription"\x8b\x01\n\x16MemoryLogRawAllocation\x12\x0f\n\x07step_id\x18\x01 \x01(\x03\x12\x11\n\toperation\x18\x02 \x01(\t\x12\x11\n\tnum_bytes\x18\x03 \x01(\x03\x12\x0b\n\x03ptr\x18\x04 \x01(\x04\x12\x15\n\rallocation_id\x18\x05 \x01(\x03\x12\x16\n\x0eallocator_name\x18\x06 \x01(\t"\x7f\n\x18MemoryLogRawDeallocation\x12\x0f\n\x07step_id\x18\x01 \x01(\x03\x12\x11\n\toperation\x18\x02 \x01(\t\x12\x15\n\rallocation_id\x18\x03 \x01(\x03\x12\x16\n\x0eallocator_name\x18\x04 \x01(\t\x12\x10\n\x08deferred\x18\x05 \x01(\x08B\x83\x01\n\x18org.tensorflow.frameworkB\x0fLogMemoryProtosP\x01ZQgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/log_memory_go_proto\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_tensor__description__pb2.DESCRIPTOR])
_MEMORYLOGSTEP = _descriptor.Descriptor(name='MemoryLogStep', full_name='tensorflow.MemoryLogStep', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='step_id', full_name='tensorflow.MemoryLogStep.step_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='handle', full_name='tensorflow.MemoryLogStep.handle', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=110, serialized_end=158)
_MEMORYLOGTENSORALLOCATION = _descriptor.Descriptor(name='MemoryLogTensorAllocation', full_name='tensorflow.MemoryLogTensorAllocation', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='step_id', full_name='tensorflow.MemoryLogTensorAllocation.step_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='kernel_name', full_name='tensorflow.MemoryLogTensorAllocation.kernel_name', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensor', full_name='tensorflow.MemoryLogTensorAllocation.tensor', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=160, serialized_end=272)
_MEMORYLOGTENSORDEALLOCATION = _descriptor.Descriptor(name='MemoryLogTensorDeallocation', full_name='tensorflow.MemoryLogTensorDeallocation', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='allocation_id', full_name='tensorflow.MemoryLogTensorDeallocation.allocation_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='allocator_name', full_name='tensorflow.MemoryLogTensorDeallocation.allocator_name', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=274, serialized_end=350)
_MEMORYLOGTENSOROUTPUT = _descriptor.Descriptor(name='MemoryLogTensorOutput', full_name='tensorflow.MemoryLogTensorOutput', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='step_id', full_name='tensorflow.MemoryLogTensorOutput.step_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='kernel_name', full_name='tensorflow.MemoryLogTensorOutput.kernel_name', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='index', full_name='tensorflow.MemoryLogTensorOutput.index', index=2, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensor', full_name='tensorflow.MemoryLogTensorOutput.tensor', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=352, serialized_end=475)
_MEMORYLOGRAWALLOCATION = _descriptor.Descriptor(name='MemoryLogRawAllocation', full_name='tensorflow.MemoryLogRawAllocation', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='step_id', full_name='tensorflow.MemoryLogRawAllocation.step_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='operation', full_name='tensorflow.MemoryLogRawAllocation.operation', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_bytes', full_name='tensorflow.MemoryLogRawAllocation.num_bytes', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='ptr', full_name='tensorflow.MemoryLogRawAllocation.ptr', index=3, number=4, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='allocation_id', full_name='tensorflow.MemoryLogRawAllocation.allocation_id', index=4, number=5, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='allocator_name', full_name='tensorflow.MemoryLogRawAllocation.allocator_name', index=5, number=6, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=478, serialized_end=617)
_MEMORYLOGRAWDEALLOCATION = _descriptor.Descriptor(name='MemoryLogRawDeallocation', full_name='tensorflow.MemoryLogRawDeallocation', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='step_id', full_name='tensorflow.MemoryLogRawDeallocation.step_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='operation', full_name='tensorflow.MemoryLogRawDeallocation.operation', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='allocation_id', full_name='tensorflow.MemoryLogRawDeallocation.allocation_id', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='allocator_name', full_name='tensorflow.MemoryLogRawDeallocation.allocator_name', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='deferred', full_name='tensorflow.MemoryLogRawDeallocation.deferred', index=4, number=5, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=619, serialized_end=746)
_MEMORYLOGTENSORALLOCATION.fields_by_name['tensor'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__description__pb2._TENSORDESCRIPTION
_MEMORYLOGTENSOROUTPUT.fields_by_name['tensor'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__description__pb2._TENSORDESCRIPTION
DESCRIPTOR.message_types_by_name['MemoryLogStep'] = _MEMORYLOGSTEP
DESCRIPTOR.message_types_by_name['MemoryLogTensorAllocation'] = _MEMORYLOGTENSORALLOCATION
DESCRIPTOR.message_types_by_name['MemoryLogTensorDeallocation'] = _MEMORYLOGTENSORDEALLOCATION
DESCRIPTOR.message_types_by_name['MemoryLogTensorOutput'] = _MEMORYLOGTENSOROUTPUT
DESCRIPTOR.message_types_by_name['MemoryLogRawAllocation'] = _MEMORYLOGRAWALLOCATION
DESCRIPTOR.message_types_by_name['MemoryLogRawDeallocation'] = _MEMORYLOGRAWDEALLOCATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
MemoryLogStep = _reflection.GeneratedProtocolMessageType('MemoryLogStep', (_message.Message,), {'DESCRIPTOR': _MEMORYLOGSTEP, '__module__': 'tensorflow.core.framework.log_memory_pb2'})
_sym_db.RegisterMessage(MemoryLogStep)
MemoryLogTensorAllocation = _reflection.GeneratedProtocolMessageType('MemoryLogTensorAllocation', (_message.Message,), {'DESCRIPTOR': _MEMORYLOGTENSORALLOCATION, '__module__': 'tensorflow.core.framework.log_memory_pb2'})
_sym_db.RegisterMessage(MemoryLogTensorAllocation)
MemoryLogTensorDeallocation = _reflection.GeneratedProtocolMessageType('MemoryLogTensorDeallocation', (_message.Message,), {'DESCRIPTOR': _MEMORYLOGTENSORDEALLOCATION, '__module__': 'tensorflow.core.framework.log_memory_pb2'})
_sym_db.RegisterMessage(MemoryLogTensorDeallocation)
MemoryLogTensorOutput = _reflection.GeneratedProtocolMessageType('MemoryLogTensorOutput', (_message.Message,), {'DESCRIPTOR': _MEMORYLOGTENSOROUTPUT, '__module__': 'tensorflow.core.framework.log_memory_pb2'})
_sym_db.RegisterMessage(MemoryLogTensorOutput)
MemoryLogRawAllocation = _reflection.GeneratedProtocolMessageType('MemoryLogRawAllocation', (_message.Message,), {'DESCRIPTOR': _MEMORYLOGRAWALLOCATION, '__module__': 'tensorflow.core.framework.log_memory_pb2'})
_sym_db.RegisterMessage(MemoryLogRawAllocation)
MemoryLogRawDeallocation = _reflection.GeneratedProtocolMessageType('MemoryLogRawDeallocation', (_message.Message,), {'DESCRIPTOR': _MEMORYLOGRAWDEALLOCATION, '__module__': 'tensorflow.core.framework.log_memory_pb2'})
_sym_db.RegisterMessage(MemoryLogRawDeallocation)
DESCRIPTOR._options = None



from typing import Union, NamedTuple, Tuple
import errno
import os

from .pb.tensorflow.core.protobuf import error_codes_pb2 as error
from . import core, strings, platform

ErrorType = int
MsgType = Union[str, core.StringPiece]

def error_name(code: ErrorType) -> str:
  if code == error.OK:
    return "OK"
  elif code == error.CANCELLED:
    return "Cancelled"
  elif code == error.UNKNOWN:
    return "Unknown"
  elif code == error.INVALID_ARGUMENT:
    return "Invalid argument"
  elif code == error.DEADLINE_EXCEEDED:
    return "Deadline exceeded"
  elif code == error.NOT_FOUND:
    return "Not found"
  elif code == error.ALREADY_EXISTS:
    return "Already exists"
  elif code == error.PERMISSION_DENIED:
    return "Permission denied"
  elif code == error.UNAUTHENTICATED:
    return "Unauthenticated"
  elif code == error.RESOURCE_EXHAUSTED:
    return "Resource exhausted"
  elif code == error.FAILED_PRECONDITION:
    return "Failed precondition"
  elif code == error.ABORTED:
    return "Aborted"
  elif code == error.OUT_OF_RANGE:
    return "Out of range"
  elif code == error.UNIMPLEMENTED:
    return "Unimplemented"
  elif code == error.INTERNAL:
    return "Internal"
  elif code == error.UNAVAILABLE:
    return "Unavailable"
  elif code == error.DATA_LOSS:
    return "Data loss"
  else:
    return "Unknown code(%d)" % code


class Status(Exception):
  class State(NamedTuple):
    code: ErrorType
    msg: str

  def __init__(self, code: ErrorType = error.OK, msg: MsgType = None):
    if code == error.OK:
      self._state = None
      super().__init__()
    else:
      assert msg is not None
      self._state = None if code == error.OK else Status.State(code, str(msg))
      super().__init__(self._state.msg)

  @staticmethod
  def OK():
    return Status()

  def ok(self) -> bool:
    return self._state is None

  def code(self) -> ErrorType:
    return error.OK if self.ok() else self._state.code

  def error_message(self) -> str:
    return "" if self.ok() else self._state.msg

  def update(self, other):
    """If `ok()`, stores `new_status` into `*this`.  If `!ok()`,
    preserves the current status, but may augment with additional
    information about `new_status`.
    Convenient way of keeping track of the first error encountered.
    Instead of:
      `if (overall_status.ok()) overall_status = new_status`
    Use:
      `overall_status.Update(new_status);`"""
    if self.ok():
      self._state = other._state

  def to_string(self) -> str:
    """Return a string representation of this status suitable for
    printing. Returns the string `"OK"` for success."""
    if self._state is None:
      return "OK"
    else:
      result = error_name(self.code())
      result += ": "
      result += self._state.msg
      return result

  def __str__(self):
    return self.to_string()

  def __repr__(self):
    return f"Status({self.to_string()!r})"

  def __eq__(self, other):
    return isinstance(other, Status) and (self._state == other._state or self.to_string() == other.to_string())

  def __ne__(self, other):
    return not (self == other)


# DECLARE_ERROR(InvalidArgument, INVALID_ARGUMENT)
class InvalidArgument(Status):
  def __init__(self, *msg):
    super().__init__(error.INVALID_ARGUMENT, strings.str_cat(*msg))

def is_invalid_argument(status: Status):
  return status.code() == error.INVALID_ARGUMENT


# DECLARE_ERROR(NotFound, NOT_FOUND)
class NotFound(Status):
  def __init__(self, *msg):
    super().__init__(error.NOT_FOUND, strings.str_cat(*msg))

def is_not_found(status: Status):
  return status.code() == error.NOT_FOUND


# DECLARE_ERROR(AlreadyExists, ALREADY_EXISTS)
class AlreadyExists(Status):
  def __init__(self, *msg):
    super().__init__(error.ALREADY_EXISTS, strings.str_cat(*msg))

def is_already_exists(status: Status):
  return status.code() == error.ALREADY_EXISTS


# DECLARE_ERROR(ResourceExhausted, RESOURCE_EXHAUSTED)
class ResourceExhausted(Status):
  def __init__(self, *msg):
    super().__init__(error.RESOURCE_EXHAUSTED, strings.str_cat(*msg))

def is_resource_exhausted(status: Status):
  return status.code() == error.RESOURCE_EXHAUSTED


# DECLARE_ERROR(Unavailable, UNAVAILABLE)
class Unavailable(Status):
  def __init__(self, *msg):
    super().__init__(error.UNAVAILABLE, strings.str_cat(*msg))

def is_unavailable(status: Status):
  return status.code() == error.UNAVAILABLE


# DECLARE_ERROR(FailedPrecondition, FAILED_PRECONDITION)
class FailedPrecondition(Status):
  def __init__(self, *msg):
    super().__init__(error.FAILED_PRECONDITION, strings.str_cat(*msg))

def is_failed_precondition(status: Status):
  return status.code() == error.FAILED_PRECONDITION


# DECLARE_ERROR(OutOfRange, OUT_OF_RANGE)
class OutOfRange(Status):
  def __init__(self, *msg):
    super().__init__(error.OUT_OF_RANGE, strings.str_cat(*msg))

def is_out_of_range(status: Status):
  return status.code() == error.OUT_OF_RANGE


# DECLARE_ERROR(Unimplemented, UNIMPLEMENTED)
class Unimplemented(Status):
  def __init__(self, *msg):
    super().__init__(error.UNIMPLEMENTED, strings.str_cat(*msg))

def is_unimplemented(status: Status):
  return status.code() == error.UNIMPLEMENTED


# DECLARE_ERROR(Internal, INTERNAL)
class Internal(Status):
  def __init__(self, *msg):
    super().__init__(error.INTERNAL, strings.str_cat(*msg))

def is_internal(status: Status):
  return status.code() == error.INTERNAL


# DECLARE_ERROR(Aborted, ABORTED)
class Aborted(Status):
  def __init__(self, *msg):
    super().__init__(error.ABORTED, strings.str_cat(*msg))

def is_aborted(status: Status):
  return status.code() == error.ABORTED


# DECLARE_ERROR(DeadlineExceeded, DEADLINE_EXCEEDED)
class DeadlineExceeded(Status):
  def __init__(self, *msg):
    super().__init__(error.DEADLINE_EXCEEDED, strings.str_cat(*msg))

def is_deadline_exceeded(status: Status):
  return status.code() == error.DEADLINE_EXCEEDED


# DECLARE_ERROR(DataLoss, DATA_LOSS)
class DataLoss(Status):
  def __init__(self, *msg):
    super().__init__(error.DATA_LOSS, strings.str_cat(*msg))

def is_data_loss(status: Status):
  return status.code() == error.DATA_LOSS


# DECLARE_ERROR(Unknown, UNKNOWN)
class Unknown(Status):
  def __init__(self, *msg):
    super().__init__(error.UNKNOWN, strings.str_cat(*msg))

def is_unknown(status: Status):
  return status.code() == error.UNKNOWN


# DECLARE_ERROR(PermissionDenied, PERMISSION_DENIED)
class PermissionDenied(Status):
  def __init__(self, *msg):
    super().__init__(error.PERMISSION_DENIED, strings.str_cat(*msg))

def is_permission_denied(status: Status):
  return status.code() == error.PERMISSION_DENIED


# DECLARE_ERROR(Unauthenticated, UNAUTHENTICATED)
class Unauthenticated(Status):
  def __init__(self, *msg):
    super().__init__(error.UNAUTHENTICATED, strings.str_cat(*msg))

def is_unauthenticated(status: Status):
  return status.code() == error.UNAUTHENTICATED


class IOError(Status):
  def __init__(self, context, err_number: int):
    code = errno_to_code(err_number)
    super().__init__(code, strings.str_cat(context, "; ", os.strerror(code)))


def errno_to_code(err_number: int) -> ErrorType:
  if err_number == 0:
    return error.OK

  if err_number == errno.EINVAL:        # Invalid argument
    return error.INVALID_ARGUMENT
  if err_number == errno.ENAMETOOLONG:  # Filename too long
    return error.INVALID_ARGUMENT
  if err_number == errno.E2BIG:         # Argument list too long
    return error.INVALID_ARGUMENT
  if err_number == errno.EDESTADDRREQ:  # Destination address required
    return error.INVALID_ARGUMENT
  if err_number == errno.EDOM:          # Mathematics argument out of domain of function
    return error.INVALID_ARGUMENT
  if err_number == errno.EFAULT:        # Bad address
    return error.INVALID_ARGUMENT
  if err_number == errno.EILSEQ:        # Illegal byte sequence
    return error.INVALID_ARGUMENT
  if err_number == errno.ENOPROTOOPT:   # Protocol not available
    return error.INVALID_ARGUMENT
  if err_number == errno.ENOSTR:        # Not a STREAM
    return error.INVALID_ARGUMENT
  if err_number == errno.ENOTSOCK:      # Not a socket
    return error.INVALID_ARGUMENT
  if err_number == errno.ENOTTY:        # Inappropriate I/O control operation
    return error.INVALID_ARGUMENT
  if err_number == errno.EPROTOTYPE:    # Protocol wrong type for socket
    return error.INVALID_ARGUMENT
  if err_number == errno.ESPIPE:        # Invalid seek
    return error.INVALID_ARGUMENT

  if err_number == errno.ETIMEDOUT:  # Connection timed out
    return error.DEADLINE_EXCEEDED
  if err_number == errno.ETIME:      # Timer expired
    return error.DEADLINE_EXCEEDED

  if err_number == errno.ENODEV:  # No such device
    return error.NOT_FOUND
  if err_number == errno.ENOENT:  # No such file or directory
    return error.NOT_FOUND
  if err_number == errno.ENXIO:   # No such device or address
    return error.NOT_FOUND
  if err_number == errno.ESRCH:   # No such process
    return error.NOT_FOUND

  if err_number == errno.EEXIST:         # File exists
    return error.ALREADY_EXISTS
  if err_number == errno.EADDRNOTAVAIL:  # Address not available
    return error.ALREADY_EXISTS
  if err_number == errno.EALREADY:       # Connection already in progress
    return error.ALREADY_EXISTS

  if err_number == errno.EPERM:   # Operation not permitted
    return error.PERMISSION_DENIED
  if err_number == errno.EACCES:  # Permission denied
    return error.PERMISSION_DENIED
  if err_number == errno.EROFS:   # Read only file system
    return error.PERMISSION_DENIED

  if err_number == errno.ENOTEMPTY:   # Directory not empty
    return error.FAILED_PRECONDITION
  if err_number == errno.EISDIR:      # Is a directory
    return error.FAILED_PRECONDITION
  if err_number == errno.ENOTDIR:     # Not a directory
    return error.FAILED_PRECONDITION
  if err_number == errno.EADDRINUSE:  # Address already in use
    return error.FAILED_PRECONDITION
  if err_number == errno.EBADF:       # Invalid file descriptor
    return error.FAILED_PRECONDITION
  if err_number == errno.EBUSY:       # Device or resource busy
    return error.FAILED_PRECONDITION
  if err_number == errno.ECHILD:      # No child processes
    return error.FAILED_PRECONDITION
  if err_number == errno.EISCONN:     # Socket is connected
    return error.FAILED_PRECONDITION
  if not platform.is_windows_platform() and not platform.is_haiku_platform():
    if err_number == errno.ENOTBLK:  # Block device required
      return error.FAILED_PRECONDITION
  if err_number == errno.ENOTCONN:  # The socket is not connected
    return error.FAILED_PRECONDITION
  if err_number == errno.EPIPE:     # Broken pipe
    return error.FAILED_PRECONDITION
  if not platform.is_windows_platform():
    if err_number == errno.ESHUTDOWN:  # Cannot send after transport endpoint shutdown
      return error.FAILED_PRECONDITION
  if err_number == errno.ETXTBSY:  # Text file busy
    return error.FAILED_PRECONDITION

  if err_number == errno.ENOSPC:  # No space left on device
    return error.RESOURCE_EXHAUSTED
  if not platform.is_windows_platform():
    if err_number == errno.EDQUOT:  # Disk quota exceeded
      return error.RESOURCE_EXHAUSTED
  if err_number == errno.EMFILE:   # Too many open files
    return error.RESOURCE_EXHAUSTED
  if err_number == errno.EMLINK:   # Too many links
    return error.RESOURCE_EXHAUSTED
  if err_number == errno.ENFILE:   # Too many open files in system
    return error.RESOURCE_EXHAUSTED
  if err_number == errno.ENOBUFS:  # No buffer space available
    return error.RESOURCE_EXHAUSTED
  if err_number == errno.ENODATA:  # No message is available on the STREAM read queue
    return error.RESOURCE_EXHAUSTED
  if err_number == errno.ENOMEM:   # Not enough space
    return error.RESOURCE_EXHAUSTED
  if err_number == errno.ENOSR:    # No STREAM resources
    return error.RESOURCE_EXHAUSTED
  if not platform.is_windows_platform() and not platform.is_haiku_platform():
    if err_number == errno.EUSERS:  # Too many users
      return error.RESOURCE_EXHAUSTED

  if err_number == errno.EFBIG:      # File too large
    return error.OUT_OF_RANGE
  if err_number == errno.EOVERFLOW:  # Value too large to be stored in data type
    return error.OUT_OF_RANGE
  if err_number == errno.ERANGE:     # Result too large
    return error.OUT_OF_RANGE

  if err_number == errno.ENOSYS:        # Function not implemented
    return error.UNIMPLEMENTED
  if err_number == errno.ENOTSUP:       # Operation not supported
    return error.UNIMPLEMENTED
  if err_number == errno.EAFNOSUPPORT:  # Address family not supported
    return error.UNIMPLEMENTED
  if not platform.is_windows_platform():
    if err_number == errno.EPFNOSUPPORT:  # Protocol family not supported
      return error.UNIMPLEMENTED
  if err_number == errno.EPROTONOSUPPORT:  # Protocol not supported
    return error.UNIMPLEMENTED
  if not platform.is_windows_platform() and not platform.is_haiku_platform():
    if err_number == errno.ESOCKTNOSUPPORT:  # Socket type not supported
      return error.UNIMPLEMENTED
  if err_number == errno.EXDEV:  # Improper link
    return error.UNIMPLEMENTED

  if err_number == errno.EAGAIN:        # Resource temporarily unavailable
    return error.UNAVAILABLE
  if err_number == errno.ECONNREFUSED:  # Connection refused
    return error.UNAVAILABLE
  if err_number == errno.ECONNABORTED:  # Connection aborted
    return error.UNAVAILABLE
  if err_number == errno.ECONNRESET:    # Connection reset
    return error.UNAVAILABLE
  if err_number == errno.EINTR:         # Interrupted function call
    return error.UNAVAILABLE
  if not platform.is_windows_platform():
    if err_number == errno.EHOSTDOWN:  # Host is down
      return error.UNAVAILABLE
  if err_number == errno.EHOSTUNREACH:  # Host is unreachable
    return error.UNAVAILABLE
  if err_number == errno.ENETDOWN:      # Network is down
    return error.UNAVAILABLE
  if err_number == errno.ENETRESET:     # Connection aborted by network
    return error.UNAVAILABLE
  if err_number == errno.ENETUNREACH:   # Network unreachable
    return error.UNAVAILABLE
  if err_number == errno.ENOLCK:        # No locks available
    return error.UNAVAILABLE
  if err_number == errno.ENOLINK:       # Link has been severed
    return error.UNAVAILABLE
  if not (platform.is_apple_platform() or platform.is_freebsd_platform() or platform.is_windows_platform()
          or platform.is_haiku_platform()):
    if err_number == errno.ENONET:  # Machine is not on the network
      return error.UNAVAILABLE

  if err_number == errno.EDEADLK:  # Resource deadlock avoided
    return error.ABORTED
  if not platform.is_windows_platform():
    if err_number == errno.ESTALE:  # Stale file handle
      return error.ABORTED

  if err_number == errno.ECANCELED:  # Operation cancelled
    return error.CANCELLED

  # NOTE: If you get any of the following (especially in a
  # reproducible way) and can propose a better mapping,
  # please email the owners about updating this mapping.

  if err_number == errno.EBADMSG:      # Bad message
    return error.UNKNOWN
  if err_number == errno.EIDRM:        # Identifier removed
    return error.UNKNOWN
  if err_number == errno.EINPROGRESS:  # Operation in progress
    return error.UNKNOWN
  if err_number == errno.EIO:          # I/O error
    return error.UNKNOWN
  if err_number == errno.ELOOP:        # Too many levels of symbolic links
    return error.UNKNOWN
  if err_number == errno.ENOEXEC:      # Exec format error
    return error.UNKNOWN
  if err_number == errno.ENOMSG:       # No message of the desired type
    return error.UNKNOWN
  if err_number == errno.EPROTO:       # Protocol error
    return error.UNKNOWN
  if not platform.is_windows_platform() and not platform.is_haiku_platform():
    if err_number == errno.EREMOTE:  # Object is remote
      return error.UNKNOWN

  return error.UNKNOWN

def raise_if_error(arg: Union[Status, Tuple]):
  status, *rest = (arg,) if not isinstance(arg, tuple) else arg
  if not status.ok():
    raise status
  if len(rest) > 1:
    return rest
  elif len(rest) == 1:
    return rest[0]




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ......tensorflow.compiler.xla.python.tpu_driver import tpu_driver_pb2 as tensorflow_dot_compiler_dot_xla_dot_python_dot_tpu__driver_dot_tpu__driver__pb2
from ......tensorflow.compiler.xla.service import hlo_pb2 as tensorflow_dot_compiler_dot_xla_dot_service_dot_hlo__pb2
from ......tensorflow.compiler.xla import xla_data_pb2 as tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/compiler/xla/python/tpu_driver/tpu_service.proto', package='tpu_driver', syntax='proto2', serialized_options=b'H\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n;tensorflow/compiler/xla/python/tpu_driver/tpu_service.proto\x12\ntpu_driver\x1a:tensorflow/compiler/xla/python/tpu_driver/tpu_driver.proto\x1a)tensorflow/compiler/xla/service/hlo.proto\x1a&tensorflow/compiler/xla/xla_data.proto".\n\rStatusMessage\x12\x0c\n\x04code\x18\x01 \x02(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t"\x8b\x01\n\x0fAllocateRequest\x12\x0f\n\x07core_id\x18\x01 \x02(\x05\x12(\n\x06region\x18\x02 \x02(\x0e2\x18.tpu_driver.MemoryRegion\x12\x13\n\tnum_bytes\x18\x03 \x01(\x03H\x00\x12 \n\x05shape\x18\x04 \x01(\x0b2\x0f.xla.ShapeProtoH\x00B\x06\n\x04size"c\n\x14AllocateTupleRequest\x12\x0f\n\x07core_id\x18\x01 \x02(\x05\x12(\n\x06region\x18\x02 \x02(\x0e2\x18.tpu_driver.MemoryRegion\x12\x10\n\x08children\x18\x03 \x03(\x03"#\n\x11DeallocateRequest\x12\x0e\n\x06handle\x18\x01 \x02(\x03">\n\x17TransferToDeviceRequest\x12\x15\n\rtarget_handle\x18\x01 \x02(\x03\x12\x0c\n\x04data\x18\x02 \x02(\x0c"2\n\x19TransferFromDeviceRequest\x12\x15\n\rsource_handle\x18\x01 \x02(\x03"*\n\x1aTransferFromDeviceResponse\x12\x0c\n\x04data\x18\x02 \x02(\x0c"Q\n!TransferFromDeviceToDeviceRequest\x12\x15\n\rsource_handle\x18\x01 \x02(\x03\x12\x15\n\rtarget_handle\x18\x02 \x02(\x03"J\n\x0eCompileRequest\x12"\n\x0bhlo_program\x18\x01 \x02(\x0b2\r.xla.HloProto\x12\x14\n\x0cnum_replicas\x18\x02 \x01(\x03"H\n\x17CompiledProgramMetadata\x12-\n\rprogram_shape\x18\x01 \x02(\x0b2\x16.xla.ProgramShapeProto"H\n\x0fCompileResponse\x125\n\x08metadata\x18\x01 \x02(\x0b2#.tpu_driver.CompiledProgramMetadata"F\n\x12LoadProgramRequest\x12\x0f\n\x07core_id\x18\x01 \x02(\x05\x12\x1f\n\x17compiled_program_handle\x18\x02 \x02(\x03"5\n\x14UnloadProgramRequest\x12\x1d\n\x15loaded_program_handle\x18\x01 \x02(\x03"\x93\x01\n\x0eExecuteRequest\x12\x1d\n\x15loaded_program_handle\x18\x01 \x02(\x03\x12\x14\n\x0cinput_handle\x18\x02 \x03(\x03\x12\x15\n\routput_handle\x18\x03 \x03(\x03\x125\n\x11device_assignment\x18\x04 \x01(\x0b2\x1a.xla.DeviceAssignmentProto"\xb4\x05\n\rStreamRequest\x12.\n\x05entry\x18\x1e \x03(\x0b2\x1f.tpu_driver.StreamRequest.Entry\x1a\xf2\x04\n\x05Entry\x12,\n\x05alloc\x18\x01 \x01(\x0b2\x1b.tpu_driver.AllocateRequestH\x00\x127\n\x0balloc_tuple\x18\x02 \x01(\x0b2 .tpu_driver.AllocateTupleRequestH\x00\x120\n\x07dealloc\x18\x03 \x01(\x0b2\x1d.tpu_driver.DeallocateRequestH\x00\x12:\n\x0btransfer_to\x18\x04 \x01(\x0b2#.tpu_driver.TransferToDeviceRequestH\x00\x12>\n\rtransfer_from\x18\x05 \x01(\x0b2%.tpu_driver.TransferFromDeviceRequestH\x00\x12I\n\x10transfer_from_to\x18\n \x01(\x0b2-.tpu_driver.TransferFromDeviceToDeviceRequestH\x00\x12-\n\x07compile\x18\x06 \x01(\x0b2\x1a.tpu_driver.CompileRequestH\x00\x12.\n\x04load\x18\x07 \x01(\x0b2\x1e.tpu_driver.LoadProgramRequestH\x00\x122\n\x06unload\x18\x08 \x01(\x0b2 .tpu_driver.UnloadProgramRequestH\x00\x12-\n\x07execute\x18\t \x01(\x0b2\x1a.tpu_driver.ExecuteRequestH\x00\x12\x13\n\x0bwait_for_id\x18\x14 \x03(\x03\x12\x14\n\x0coperation_id\x18\x15 \x02(\x03\x12\x11\n\tthread_id\x18\x16 \x01(\x03B\t\n\x07request"\x89\x02\n\x0eStreamResponse\x12/\n\x05entry\x18\x14 \x03(\x0b2 .tpu_driver.StreamResponse.Entry\x1a\xc5\x01\n\x05Entry\x12?\n\rtransfer_from\x18\x03 \x01(\x0b2&.tpu_driver.TransferFromDeviceResponseH\x00\x12.\n\x07compile\x18\x04 \x01(\x0b2\x1b.tpu_driver.CompileResponseH\x00\x12)\n\x06status\x18\n \x02(\x0b2\x19.tpu_driver.StatusMessage\x12\x14\n\x0coperation_id\x18\x0b \x02(\x03B\n\n\x08response"(\n\x0bOpenRequest\x12\x19\n\x0eclient_version\x18\x01 \x01(\x05:\x010"F\n\x0cOpenResponse\x12\x11\n\tclient_id\x18\x01 \x02(\r\x12#\n\x15max_idle_time_seconds\x18\x02 \x01(\x05:\x043600"!\n\x0cCloseRequest\x12\x11\n\tclient_id\x18\x01 \x02(\x07"\x0f\n\rCloseResponse"\x0e\n\x0cResetRequest"\x0f\n\rResetResponse"\x18\n\x16QuerySystemInfoRequest"F\n\x17QuerySystemInfoResponse\x12+\n\x0bsystem_info\x18\x01 \x02(\x0b2\x16.tpu_driver.SystemInfo2\xef\x02\n\x0eCloudTpuDriver\x129\n\x04Open\x12\x17.tpu_driver.OpenRequest\x1a\x18.tpu_driver.OpenResponse\x12<\n\x05Close\x12\x18.tpu_driver.CloseRequest\x1a\x19.tpu_driver.CloseResponse\x12<\n\x05Reset\x12\x18.tpu_driver.ResetRequest\x1a\x19.tpu_driver.ResetResponse\x12Z\n\x0fQuerySystemInfo\x12".tpu_driver.QuerySystemInfoRequest\x1a#.tpu_driver.QuerySystemInfoResponse\x12J\n\rStreamExecute\x12\x19.tpu_driver.StreamRequest\x1a\x1a.tpu_driver.StreamResponse(\x010\x01B\x02H\x01', dependencies=[tensorflow_dot_compiler_dot_xla_dot_python_dot_tpu__driver_dot_tpu__driver__pb2.DESCRIPTOR, tensorflow_dot_compiler_dot_xla_dot_service_dot_hlo__pb2.DESCRIPTOR, tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2.DESCRIPTOR])
_STATUSMESSAGE = _descriptor.Descriptor(name='StatusMessage', full_name='tpu_driver.StatusMessage', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='code', full_name='tpu_driver.StatusMessage.code', index=0, number=1, type=5, cpp_type=1, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='message', full_name='tpu_driver.StatusMessage.message', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=218, serialized_end=264)
_ALLOCATEREQUEST = _descriptor.Descriptor(name='AllocateRequest', full_name='tpu_driver.AllocateRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='core_id', full_name='tpu_driver.AllocateRequest.core_id', index=0, number=1, type=5, cpp_type=1, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='region', full_name='tpu_driver.AllocateRequest.region', index=1, number=2, type=14, cpp_type=8, label=2, has_default_value=False, default_value=1, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_bytes', full_name='tpu_driver.AllocateRequest.num_bytes', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='shape', full_name='tpu_driver.AllocateRequest.shape', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='size', full_name='tpu_driver.AllocateRequest.size', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=267, serialized_end=406)
_ALLOCATETUPLEREQUEST = _descriptor.Descriptor(name='AllocateTupleRequest', full_name='tpu_driver.AllocateTupleRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='core_id', full_name='tpu_driver.AllocateTupleRequest.core_id', index=0, number=1, type=5, cpp_type=1, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='region', full_name='tpu_driver.AllocateTupleRequest.region', index=1, number=2, type=14, cpp_type=8, label=2, has_default_value=False, default_value=1, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='children', full_name='tpu_driver.AllocateTupleRequest.children', index=2, number=3, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=408, serialized_end=507)
_DEALLOCATEREQUEST = _descriptor.Descriptor(name='DeallocateRequest', full_name='tpu_driver.DeallocateRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='handle', full_name='tpu_driver.DeallocateRequest.handle', index=0, number=1, type=3, cpp_type=2, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=509, serialized_end=544)
_TRANSFERTODEVICEREQUEST = _descriptor.Descriptor(name='TransferToDeviceRequest', full_name='tpu_driver.TransferToDeviceRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='target_handle', full_name='tpu_driver.TransferToDeviceRequest.target_handle', index=0, number=1, type=3, cpp_type=2, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='data', full_name='tpu_driver.TransferToDeviceRequest.data', index=1, number=2, type=12, cpp_type=9, label=2, has_default_value=False, default_value=b'', message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=546, serialized_end=608)
_TRANSFERFROMDEVICEREQUEST = _descriptor.Descriptor(name='TransferFromDeviceRequest', full_name='tpu_driver.TransferFromDeviceRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='source_handle', full_name='tpu_driver.TransferFromDeviceRequest.source_handle', index=0, number=1, type=3, cpp_type=2, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=610, serialized_end=660)
_TRANSFERFROMDEVICERESPONSE = _descriptor.Descriptor(name='TransferFromDeviceResponse', full_name='tpu_driver.TransferFromDeviceResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='data', full_name='tpu_driver.TransferFromDeviceResponse.data', index=0, number=2, type=12, cpp_type=9, label=2, has_default_value=False, default_value=b'', message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=662, serialized_end=704)
_TRANSFERFROMDEVICETODEVICEREQUEST = _descriptor.Descriptor(name='TransferFromDeviceToDeviceRequest', full_name='tpu_driver.TransferFromDeviceToDeviceRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='source_handle', full_name='tpu_driver.TransferFromDeviceToDeviceRequest.source_handle', index=0, number=1, type=3, cpp_type=2, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='target_handle', full_name='tpu_driver.TransferFromDeviceToDeviceRequest.target_handle', index=1, number=2, type=3, cpp_type=2, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=706, serialized_end=787)
_COMPILEREQUEST = _descriptor.Descriptor(name='CompileRequest', full_name='tpu_driver.CompileRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='hlo_program', full_name='tpu_driver.CompileRequest.hlo_program', index=0, number=1, type=11, cpp_type=10, label=2, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_replicas', full_name='tpu_driver.CompileRequest.num_replicas', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=789, serialized_end=863)
_COMPILEDPROGRAMMETADATA = _descriptor.Descriptor(name='CompiledProgramMetadata', full_name='tpu_driver.CompiledProgramMetadata', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='program_shape', full_name='tpu_driver.CompiledProgramMetadata.program_shape', index=0, number=1, type=11, cpp_type=10, label=2, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=865, serialized_end=937)
_COMPILERESPONSE = _descriptor.Descriptor(name='CompileResponse', full_name='tpu_driver.CompileResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='metadata', full_name='tpu_driver.CompileResponse.metadata', index=0, number=1, type=11, cpp_type=10, label=2, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=939, serialized_end=1011)
_LOADPROGRAMREQUEST = _descriptor.Descriptor(name='LoadProgramRequest', full_name='tpu_driver.LoadProgramRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='core_id', full_name='tpu_driver.LoadProgramRequest.core_id', index=0, number=1, type=5, cpp_type=1, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='compiled_program_handle', full_name='tpu_driver.LoadProgramRequest.compiled_program_handle', index=1, number=2, type=3, cpp_type=2, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=1013, serialized_end=1083)
_UNLOADPROGRAMREQUEST = _descriptor.Descriptor(name='UnloadProgramRequest', full_name='tpu_driver.UnloadProgramRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='loaded_program_handle', full_name='tpu_driver.UnloadProgramRequest.loaded_program_handle', index=0, number=1, type=3, cpp_type=2, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=1085, serialized_end=1138)
_EXECUTEREQUEST = _descriptor.Descriptor(name='ExecuteRequest', full_name='tpu_driver.ExecuteRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='loaded_program_handle', full_name='tpu_driver.ExecuteRequest.loaded_program_handle', index=0, number=1, type=3, cpp_type=2, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_handle', full_name='tpu_driver.ExecuteRequest.input_handle', index=1, number=2, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_handle', full_name='tpu_driver.ExecuteRequest.output_handle', index=2, number=3, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_assignment', full_name='tpu_driver.ExecuteRequest.device_assignment', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=1141, serialized_end=1288)
_STREAMREQUEST_ENTRY = _descriptor.Descriptor(name='Entry', full_name='tpu_driver.StreamRequest.Entry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='alloc', full_name='tpu_driver.StreamRequest.Entry.alloc', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='alloc_tuple', full_name='tpu_driver.StreamRequest.Entry.alloc_tuple', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dealloc', full_name='tpu_driver.StreamRequest.Entry.dealloc', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='transfer_to', full_name='tpu_driver.StreamRequest.Entry.transfer_to', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='transfer_from', full_name='tpu_driver.StreamRequest.Entry.transfer_from', index=4, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='transfer_from_to', full_name='tpu_driver.StreamRequest.Entry.transfer_from_to', index=5, number=10, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='compile', full_name='tpu_driver.StreamRequest.Entry.compile', index=6, number=6, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='load', full_name='tpu_driver.StreamRequest.Entry.load', index=7, number=7, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='unload', full_name='tpu_driver.StreamRequest.Entry.unload', index=8, number=8, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='execute', full_name='tpu_driver.StreamRequest.Entry.execute', index=9, number=9, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='wait_for_id', full_name='tpu_driver.StreamRequest.Entry.wait_for_id', index=10, number=20, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='operation_id', full_name='tpu_driver.StreamRequest.Entry.operation_id', index=11, number=21, type=3, cpp_type=2, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='thread_id', full_name='tpu_driver.StreamRequest.Entry.thread_id', index=12, number=22, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='request', full_name='tpu_driver.StreamRequest.Entry.request', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=1357, serialized_end=1983)
_STREAMREQUEST = _descriptor.Descriptor(name='StreamRequest', full_name='tpu_driver.StreamRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='entry', full_name='tpu_driver.StreamRequest.entry', index=0, number=30, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_STREAMREQUEST_ENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=1291, serialized_end=1983)
_STREAMRESPONSE_ENTRY = _descriptor.Descriptor(name='Entry', full_name='tpu_driver.StreamResponse.Entry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='transfer_from', full_name='tpu_driver.StreamResponse.Entry.transfer_from', index=0, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='compile', full_name='tpu_driver.StreamResponse.Entry.compile', index=1, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='status', full_name='tpu_driver.StreamResponse.Entry.status', index=2, number=10, type=11, cpp_type=10, label=2, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='operation_id', full_name='tpu_driver.StreamResponse.Entry.operation_id', index=3, number=11, type=3, cpp_type=2, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='response', full_name='tpu_driver.StreamResponse.Entry.response', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=2054, serialized_end=2251)
_STREAMRESPONSE = _descriptor.Descriptor(name='StreamResponse', full_name='tpu_driver.StreamResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='entry', full_name='tpu_driver.StreamResponse.entry', index=0, number=20, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_STREAMRESPONSE_ENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=1986, serialized_end=2251)
_OPENREQUEST = _descriptor.Descriptor(name='OpenRequest', full_name='tpu_driver.OpenRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='client_version', full_name='tpu_driver.OpenRequest.client_version', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=True, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=2253, serialized_end=2293)
_OPENRESPONSE = _descriptor.Descriptor(name='OpenResponse', full_name='tpu_driver.OpenResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='client_id', full_name='tpu_driver.OpenResponse.client_id', index=0, number=1, type=13, cpp_type=3, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='max_idle_time_seconds', full_name='tpu_driver.OpenResponse.max_idle_time_seconds', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=True, default_value=3600, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=2295, serialized_end=2365)
_CLOSEREQUEST = _descriptor.Descriptor(name='CloseRequest', full_name='tpu_driver.CloseRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='client_id', full_name='tpu_driver.CloseRequest.client_id', index=0, number=1, type=7, cpp_type=3, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=2367, serialized_end=2400)
_CLOSERESPONSE = _descriptor.Descriptor(name='CloseResponse', full_name='tpu_driver.CloseResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=2402, serialized_end=2417)
_RESETREQUEST = _descriptor.Descriptor(name='ResetRequest', full_name='tpu_driver.ResetRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=2419, serialized_end=2433)
_RESETRESPONSE = _descriptor.Descriptor(name='ResetResponse', full_name='tpu_driver.ResetResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=2435, serialized_end=2450)
_QUERYSYSTEMINFOREQUEST = _descriptor.Descriptor(name='QuerySystemInfoRequest', full_name='tpu_driver.QuerySystemInfoRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=2452, serialized_end=2476)
_QUERYSYSTEMINFORESPONSE = _descriptor.Descriptor(name='QuerySystemInfoResponse', full_name='tpu_driver.QuerySystemInfoResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='system_info', full_name='tpu_driver.QuerySystemInfoResponse.system_info', index=0, number=1, type=11, cpp_type=10, label=2, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=2478, serialized_end=2548)
_ALLOCATEREQUEST.fields_by_name['region'].enum_type = tensorflow_dot_compiler_dot_xla_dot_python_dot_tpu__driver_dot_tpu__driver__pb2._MEMORYREGION
_ALLOCATEREQUEST.fields_by_name['shape'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._SHAPEPROTO
_ALLOCATEREQUEST.oneofs_by_name['size'].fields.append(_ALLOCATEREQUEST.fields_by_name['num_bytes'])
_ALLOCATEREQUEST.fields_by_name['num_bytes'].containing_oneof = _ALLOCATEREQUEST.oneofs_by_name['size']
_ALLOCATEREQUEST.oneofs_by_name['size'].fields.append(_ALLOCATEREQUEST.fields_by_name['shape'])
_ALLOCATEREQUEST.fields_by_name['shape'].containing_oneof = _ALLOCATEREQUEST.oneofs_by_name['size']
_ALLOCATETUPLEREQUEST.fields_by_name['region'].enum_type = tensorflow_dot_compiler_dot_xla_dot_python_dot_tpu__driver_dot_tpu__driver__pb2._MEMORYREGION
_COMPILEREQUEST.fields_by_name['hlo_program'].message_type = tensorflow_dot_compiler_dot_xla_dot_service_dot_hlo__pb2._HLOPROTO
_COMPILEDPROGRAMMETADATA.fields_by_name['program_shape'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._PROGRAMSHAPEPROTO
_COMPILERESPONSE.fields_by_name['metadata'].message_type = _COMPILEDPROGRAMMETADATA
_EXECUTEREQUEST.fields_by_name['device_assignment'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._DEVICEASSIGNMENTPROTO
_STREAMREQUEST_ENTRY.fields_by_name['alloc'].message_type = _ALLOCATEREQUEST
_STREAMREQUEST_ENTRY.fields_by_name['alloc_tuple'].message_type = _ALLOCATETUPLEREQUEST
_STREAMREQUEST_ENTRY.fields_by_name['dealloc'].message_type = _DEALLOCATEREQUEST
_STREAMREQUEST_ENTRY.fields_by_name['transfer_to'].message_type = _TRANSFERTODEVICEREQUEST
_STREAMREQUEST_ENTRY.fields_by_name['transfer_from'].message_type = _TRANSFERFROMDEVICEREQUEST
_STREAMREQUEST_ENTRY.fields_by_name['transfer_from_to'].message_type = _TRANSFERFROMDEVICETODEVICEREQUEST
_STREAMREQUEST_ENTRY.fields_by_name['compile'].message_type = _COMPILEREQUEST
_STREAMREQUEST_ENTRY.fields_by_name['load'].message_type = _LOADPROGRAMREQUEST
_STREAMREQUEST_ENTRY.fields_by_name['unload'].message_type = _UNLOADPROGRAMREQUEST
_STREAMREQUEST_ENTRY.fields_by_name['execute'].message_type = _EXECUTEREQUEST
_STREAMREQUEST_ENTRY.containing_type = _STREAMREQUEST
_STREAMREQUEST_ENTRY.oneofs_by_name['request'].fields.append(_STREAMREQUEST_ENTRY.fields_by_name['alloc'])
_STREAMREQUEST_ENTRY.fields_by_name['alloc'].containing_oneof = _STREAMREQUEST_ENTRY.oneofs_by_name['request']
_STREAMREQUEST_ENTRY.oneofs_by_name['request'].fields.append(_STREAMREQUEST_ENTRY.fields_by_name['alloc_tuple'])
_STREAMREQUEST_ENTRY.fields_by_name['alloc_tuple'].containing_oneof = _STREAMREQUEST_ENTRY.oneofs_by_name['request']
_STREAMREQUEST_ENTRY.oneofs_by_name['request'].fields.append(_STREAMREQUEST_ENTRY.fields_by_name['dealloc'])
_STREAMREQUEST_ENTRY.fields_by_name['dealloc'].containing_oneof = _STREAMREQUEST_ENTRY.oneofs_by_name['request']
_STREAMREQUEST_ENTRY.oneofs_by_name['request'].fields.append(_STREAMREQUEST_ENTRY.fields_by_name['transfer_to'])
_STREAMREQUEST_ENTRY.fields_by_name['transfer_to'].containing_oneof = _STREAMREQUEST_ENTRY.oneofs_by_name['request']
_STREAMREQUEST_ENTRY.oneofs_by_name['request'].fields.append(_STREAMREQUEST_ENTRY.fields_by_name['transfer_from'])
_STREAMREQUEST_ENTRY.fields_by_name['transfer_from'].containing_oneof = _STREAMREQUEST_ENTRY.oneofs_by_name['request']
_STREAMREQUEST_ENTRY.oneofs_by_name['request'].fields.append(_STREAMREQUEST_ENTRY.fields_by_name['transfer_from_to'])
_STREAMREQUEST_ENTRY.fields_by_name['transfer_from_to'].containing_oneof = _STREAMREQUEST_ENTRY.oneofs_by_name['request']
_STREAMREQUEST_ENTRY.oneofs_by_name['request'].fields.append(_STREAMREQUEST_ENTRY.fields_by_name['compile'])
_STREAMREQUEST_ENTRY.fields_by_name['compile'].containing_oneof = _STREAMREQUEST_ENTRY.oneofs_by_name['request']
_STREAMREQUEST_ENTRY.oneofs_by_name['request'].fields.append(_STREAMREQUEST_ENTRY.fields_by_name['load'])
_STREAMREQUEST_ENTRY.fields_by_name['load'].containing_oneof = _STREAMREQUEST_ENTRY.oneofs_by_name['request']
_STREAMREQUEST_ENTRY.oneofs_by_name['request'].fields.append(_STREAMREQUEST_ENTRY.fields_by_name['unload'])
_STREAMREQUEST_ENTRY.fields_by_name['unload'].containing_oneof = _STREAMREQUEST_ENTRY.oneofs_by_name['request']
_STREAMREQUEST_ENTRY.oneofs_by_name['request'].fields.append(_STREAMREQUEST_ENTRY.fields_by_name['execute'])
_STREAMREQUEST_ENTRY.fields_by_name['execute'].containing_oneof = _STREAMREQUEST_ENTRY.oneofs_by_name['request']
_STREAMREQUEST.fields_by_name['entry'].message_type = _STREAMREQUEST_ENTRY
_STREAMRESPONSE_ENTRY.fields_by_name['transfer_from'].message_type = _TRANSFERFROMDEVICERESPONSE
_STREAMRESPONSE_ENTRY.fields_by_name['compile'].message_type = _COMPILERESPONSE
_STREAMRESPONSE_ENTRY.fields_by_name['status'].message_type = _STATUSMESSAGE
_STREAMRESPONSE_ENTRY.containing_type = _STREAMRESPONSE
_STREAMRESPONSE_ENTRY.oneofs_by_name['response'].fields.append(_STREAMRESPONSE_ENTRY.fields_by_name['transfer_from'])
_STREAMRESPONSE_ENTRY.fields_by_name['transfer_from'].containing_oneof = _STREAMRESPONSE_ENTRY.oneofs_by_name['response']
_STREAMRESPONSE_ENTRY.oneofs_by_name['response'].fields.append(_STREAMRESPONSE_ENTRY.fields_by_name['compile'])
_STREAMRESPONSE_ENTRY.fields_by_name['compile'].containing_oneof = _STREAMRESPONSE_ENTRY.oneofs_by_name['response']
_STREAMRESPONSE.fields_by_name['entry'].message_type = _STREAMRESPONSE_ENTRY
_QUERYSYSTEMINFORESPONSE.fields_by_name['system_info'].message_type = tensorflow_dot_compiler_dot_xla_dot_python_dot_tpu__driver_dot_tpu__driver__pb2._SYSTEMINFO
DESCRIPTOR.message_types_by_name['StatusMessage'] = _STATUSMESSAGE
DESCRIPTOR.message_types_by_name['AllocateRequest'] = _ALLOCATEREQUEST
DESCRIPTOR.message_types_by_name['AllocateTupleRequest'] = _ALLOCATETUPLEREQUEST
DESCRIPTOR.message_types_by_name['DeallocateRequest'] = _DEALLOCATEREQUEST
DESCRIPTOR.message_types_by_name['TransferToDeviceRequest'] = _TRANSFERTODEVICEREQUEST
DESCRIPTOR.message_types_by_name['TransferFromDeviceRequest'] = _TRANSFERFROMDEVICEREQUEST
DESCRIPTOR.message_types_by_name['TransferFromDeviceResponse'] = _TRANSFERFROMDEVICERESPONSE
DESCRIPTOR.message_types_by_name['TransferFromDeviceToDeviceRequest'] = _TRANSFERFROMDEVICETODEVICEREQUEST
DESCRIPTOR.message_types_by_name['CompileRequest'] = _COMPILEREQUEST
DESCRIPTOR.message_types_by_name['CompiledProgramMetadata'] = _COMPILEDPROGRAMMETADATA
DESCRIPTOR.message_types_by_name['CompileResponse'] = _COMPILERESPONSE
DESCRIPTOR.message_types_by_name['LoadProgramRequest'] = _LOADPROGRAMREQUEST
DESCRIPTOR.message_types_by_name['UnloadProgramRequest'] = _UNLOADPROGRAMREQUEST
DESCRIPTOR.message_types_by_name['ExecuteRequest'] = _EXECUTEREQUEST
DESCRIPTOR.message_types_by_name['StreamRequest'] = _STREAMREQUEST
DESCRIPTOR.message_types_by_name['StreamResponse'] = _STREAMRESPONSE
DESCRIPTOR.message_types_by_name['OpenRequest'] = _OPENREQUEST
DESCRIPTOR.message_types_by_name['OpenResponse'] = _OPENRESPONSE
DESCRIPTOR.message_types_by_name['CloseRequest'] = _CLOSEREQUEST
DESCRIPTOR.message_types_by_name['CloseResponse'] = _CLOSERESPONSE
DESCRIPTOR.message_types_by_name['ResetRequest'] = _RESETREQUEST
DESCRIPTOR.message_types_by_name['ResetResponse'] = _RESETRESPONSE
DESCRIPTOR.message_types_by_name['QuerySystemInfoRequest'] = _QUERYSYSTEMINFOREQUEST
DESCRIPTOR.message_types_by_name['QuerySystemInfoResponse'] = _QUERYSYSTEMINFORESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
StatusMessage = _reflection.GeneratedProtocolMessageType('StatusMessage', (_message.Message,), {'DESCRIPTOR': _STATUSMESSAGE, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(StatusMessage)
AllocateRequest = _reflection.GeneratedProtocolMessageType('AllocateRequest', (_message.Message,), {'DESCRIPTOR': _ALLOCATEREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(AllocateRequest)
AllocateTupleRequest = _reflection.GeneratedProtocolMessageType('AllocateTupleRequest', (_message.Message,), {'DESCRIPTOR': _ALLOCATETUPLEREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(AllocateTupleRequest)
DeallocateRequest = _reflection.GeneratedProtocolMessageType('DeallocateRequest', (_message.Message,), {'DESCRIPTOR': _DEALLOCATEREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(DeallocateRequest)
TransferToDeviceRequest = _reflection.GeneratedProtocolMessageType('TransferToDeviceRequest', (_message.Message,), {'DESCRIPTOR': _TRANSFERTODEVICEREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(TransferToDeviceRequest)
TransferFromDeviceRequest = _reflection.GeneratedProtocolMessageType('TransferFromDeviceRequest', (_message.Message,), {'DESCRIPTOR': _TRANSFERFROMDEVICEREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(TransferFromDeviceRequest)
TransferFromDeviceResponse = _reflection.GeneratedProtocolMessageType('TransferFromDeviceResponse', (_message.Message,), {'DESCRIPTOR': _TRANSFERFROMDEVICERESPONSE, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(TransferFromDeviceResponse)
TransferFromDeviceToDeviceRequest = _reflection.GeneratedProtocolMessageType('TransferFromDeviceToDeviceRequest', (_message.Message,), {'DESCRIPTOR': _TRANSFERFROMDEVICETODEVICEREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(TransferFromDeviceToDeviceRequest)
CompileRequest = _reflection.GeneratedProtocolMessageType('CompileRequest', (_message.Message,), {'DESCRIPTOR': _COMPILEREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(CompileRequest)
CompiledProgramMetadata = _reflection.GeneratedProtocolMessageType('CompiledProgramMetadata', (_message.Message,), {'DESCRIPTOR': _COMPILEDPROGRAMMETADATA, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(CompiledProgramMetadata)
CompileResponse = _reflection.GeneratedProtocolMessageType('CompileResponse', (_message.Message,), {'DESCRIPTOR': _COMPILERESPONSE, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(CompileResponse)
LoadProgramRequest = _reflection.GeneratedProtocolMessageType('LoadProgramRequest', (_message.Message,), {'DESCRIPTOR': _LOADPROGRAMREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(LoadProgramRequest)
UnloadProgramRequest = _reflection.GeneratedProtocolMessageType('UnloadProgramRequest', (_message.Message,), {'DESCRIPTOR': _UNLOADPROGRAMREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(UnloadProgramRequest)
ExecuteRequest = _reflection.GeneratedProtocolMessageType('ExecuteRequest', (_message.Message,), {'DESCRIPTOR': _EXECUTEREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(ExecuteRequest)
StreamRequest = _reflection.GeneratedProtocolMessageType('StreamRequest', (_message.Message,), {'Entry': _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), {'DESCRIPTOR': _STREAMREQUEST_ENTRY, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'}), 'DESCRIPTOR': _STREAMREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(StreamRequest)
_sym_db.RegisterMessage(StreamRequest.Entry)
StreamResponse = _reflection.GeneratedProtocolMessageType('StreamResponse', (_message.Message,), {'Entry': _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), {'DESCRIPTOR': _STREAMRESPONSE_ENTRY, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'}), 'DESCRIPTOR': _STREAMRESPONSE, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(StreamResponse)
_sym_db.RegisterMessage(StreamResponse.Entry)
OpenRequest = _reflection.GeneratedProtocolMessageType('OpenRequest', (_message.Message,), {'DESCRIPTOR': _OPENREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(OpenRequest)
OpenResponse = _reflection.GeneratedProtocolMessageType('OpenResponse', (_message.Message,), {'DESCRIPTOR': _OPENRESPONSE, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(OpenResponse)
CloseRequest = _reflection.GeneratedProtocolMessageType('CloseRequest', (_message.Message,), {'DESCRIPTOR': _CLOSEREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(CloseRequest)
CloseResponse = _reflection.GeneratedProtocolMessageType('CloseResponse', (_message.Message,), {'DESCRIPTOR': _CLOSERESPONSE, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(CloseResponse)
ResetRequest = _reflection.GeneratedProtocolMessageType('ResetRequest', (_message.Message,), {'DESCRIPTOR': _RESETREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(ResetRequest)
ResetResponse = _reflection.GeneratedProtocolMessageType('ResetResponse', (_message.Message,), {'DESCRIPTOR': _RESETRESPONSE, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(ResetResponse)
QuerySystemInfoRequest = _reflection.GeneratedProtocolMessageType('QuerySystemInfoRequest', (_message.Message,), {'DESCRIPTOR': _QUERYSYSTEMINFOREQUEST, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(QuerySystemInfoRequest)
QuerySystemInfoResponse = _reflection.GeneratedProtocolMessageType('QuerySystemInfoResponse', (_message.Message,), {'DESCRIPTOR': _QUERYSYSTEMINFORESPONSE, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_service_pb2'})
_sym_db.RegisterMessage(QuerySystemInfoResponse)
DESCRIPTOR._options = None
_CLOUDTPUDRIVER = _descriptor.ServiceDescriptor(name='CloudTpuDriver', full_name='tpu_driver.CloudTpuDriver', file=DESCRIPTOR, index=0, serialized_options=None, create_key=_descriptor._internal_create_key, serialized_start=2551, serialized_end=2918, methods=[_descriptor.MethodDescriptor(name='Open', full_name='tpu_driver.CloudTpuDriver.Open', index=0, containing_service=None, input_type=_OPENREQUEST, output_type=_OPENRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='Close', full_name='tpu_driver.CloudTpuDriver.Close', index=1, containing_service=None, input_type=_CLOSEREQUEST, output_type=_CLOSERESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='Reset', full_name='tpu_driver.CloudTpuDriver.Reset', index=2, containing_service=None, input_type=_RESETREQUEST, output_type=_RESETRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='QuerySystemInfo', full_name='tpu_driver.CloudTpuDriver.QuerySystemInfo', index=3, containing_service=None, input_type=_QUERYSYSTEMINFOREQUEST, output_type=_QUERYSYSTEMINFORESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='StreamExecute', full_name='tpu_driver.CloudTpuDriver.StreamExecute', index=4, containing_service=None, input_type=_STREAMREQUEST, output_type=_STREAMRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key)])
_sym_db.RegisterServiceDescriptor(_CLOUDTPUDRIVER)
DESCRIPTOR.services_by_name['CloudTpuDriver'] = _CLOUDTPUDRIVER




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/util/memmapped_file_system.proto', package='tensorflow', syntax='proto3', serialized_options=b'\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n0tensorflow/core/util/memmapped_file_system.proto\x12\ntensorflow"S\n#MemmappedFileSystemDirectoryElement\x12\x0e\n\x06offset\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06length\x18\x03 \x01(\x04"`\n\x1cMemmappedFileSystemDirectory\x12@\n\x07element\x18\x01 \x03(\x0b2/.tensorflow.MemmappedFileSystemDirectoryElementB\x03\xf8\x01\x01b\x06proto3')
_MEMMAPPEDFILESYSTEMDIRECTORYELEMENT = _descriptor.Descriptor(name='MemmappedFileSystemDirectoryElement', full_name='tensorflow.MemmappedFileSystemDirectoryElement', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='offset', full_name='tensorflow.MemmappedFileSystemDirectoryElement.offset', index=0, number=1, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='name', full_name='tensorflow.MemmappedFileSystemDirectoryElement.name', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='length', full_name='tensorflow.MemmappedFileSystemDirectoryElement.length', index=2, number=3, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=64, serialized_end=147)
_MEMMAPPEDFILESYSTEMDIRECTORY = _descriptor.Descriptor(name='MemmappedFileSystemDirectory', full_name='tensorflow.MemmappedFileSystemDirectory', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='element', full_name='tensorflow.MemmappedFileSystemDirectory.element', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=149, serialized_end=245)
_MEMMAPPEDFILESYSTEMDIRECTORY.fields_by_name['element'].message_type = _MEMMAPPEDFILESYSTEMDIRECTORYELEMENT
DESCRIPTOR.message_types_by_name['MemmappedFileSystemDirectoryElement'] = _MEMMAPPEDFILESYSTEMDIRECTORYELEMENT
DESCRIPTOR.message_types_by_name['MemmappedFileSystemDirectory'] = _MEMMAPPEDFILESYSTEMDIRECTORY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
MemmappedFileSystemDirectoryElement = _reflection.GeneratedProtocolMessageType('MemmappedFileSystemDirectoryElement', (_message.Message,), {'DESCRIPTOR': _MEMMAPPEDFILESYSTEMDIRECTORYELEMENT, '__module__': 'tensorflow.core.util.memmapped_file_system_pb2'})
_sym_db.RegisterMessage(MemmappedFileSystemDirectoryElement)
MemmappedFileSystemDirectory = _reflection.GeneratedProtocolMessageType('MemmappedFileSystemDirectory', (_message.Message,), {'DESCRIPTOR': _MEMMAPPEDFILESYSTEMDIRECTORY, '__module__': 'tensorflow.core.util.memmapped_file_system_pb2'})
_sym_db.RegisterMessage(MemmappedFileSystemDirectory)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/framework/variable.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x18org.tensorflow.frameworkB\x0eVariableProtosP\x01ZOgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/variable_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n(tensorflow/core/framework/variable.proto\x12\ntensorflow"\xc8\x02\n\x0bVariableDef\x12\x15\n\rvariable_name\x18\x01 \x01(\t\x12\x1a\n\x12initial_value_name\x18\x06 \x01(\t\x12\x18\n\x10initializer_name\x18\x02 \x01(\t\x12\x15\n\rsnapshot_name\x18\x03 \x01(\t\x129\n\x13save_slice_info_def\x18\x04 \x01(\x0b2\x1c.tensorflow.SaveSliceInfoDef\x12\x13\n\x0bis_resource\x18\x05 \x01(\x08\x12\x11\n\ttrainable\x18\x07 \x01(\x08\x12<\n\x0fsynchronization\x18\x08 \x01(\x0e2#.tensorflow.VariableSynchronization\x124\n\x0baggregation\x18\t \x01(\x0e2\x1f.tensorflow.VariableAggregation"`\n\x10SaveSliceInfoDef\x12\x11\n\tfull_name\x18\x01 \x01(\t\x12\x12\n\nfull_shape\x18\x02 \x03(\x03\x12\x12\n\nvar_offset\x18\x03 \x03(\x03\x12\x11\n\tvar_shape\x18\x04 \x03(\x03*\xac\x01\n\x17VariableSynchronization\x12!\n\x1dVARIABLE_SYNCHRONIZATION_AUTO\x10\x00\x12!\n\x1dVARIABLE_SYNCHRONIZATION_NONE\x10\x01\x12%\n!VARIABLE_SYNCHRONIZATION_ON_WRITE\x10\x02\x12$\n VARIABLE_SYNCHRONIZATION_ON_READ\x10\x03*\x9e\x01\n\x13VariableAggregation\x12\x1d\n\x19VARIABLE_AGGREGATION_NONE\x10\x00\x12\x1c\n\x18VARIABLE_AGGREGATION_SUM\x10\x01\x12\x1d\n\x19VARIABLE_AGGREGATION_MEAN\x10\x02\x12+\n\'VARIABLE_AGGREGATION_ONLY_FIRST_REPLICA\x10\x03B\x80\x01\n\x18org.tensorflow.frameworkB\x0eVariableProtosP\x01ZOgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/variable_go_proto\xf8\x01\x01b\x06proto3')
_VARIABLESYNCHRONIZATION = _descriptor.EnumDescriptor(name='VariableSynchronization', full_name='tensorflow.VariableSynchronization', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='VARIABLE_SYNCHRONIZATION_AUTO', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='VARIABLE_SYNCHRONIZATION_NONE', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='VARIABLE_SYNCHRONIZATION_ON_WRITE', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='VARIABLE_SYNCHRONIZATION_ON_READ', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=486, serialized_end=658)
_sym_db.RegisterEnumDescriptor(_VARIABLESYNCHRONIZATION)
VariableSynchronization = enum_type_wrapper.EnumTypeWrapper(_VARIABLESYNCHRONIZATION)
_VARIABLEAGGREGATION = _descriptor.EnumDescriptor(name='VariableAggregation', full_name='tensorflow.VariableAggregation', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='VARIABLE_AGGREGATION_NONE', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='VARIABLE_AGGREGATION_SUM', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='VARIABLE_AGGREGATION_MEAN', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='VARIABLE_AGGREGATION_ONLY_FIRST_REPLICA', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=661, serialized_end=819)
_sym_db.RegisterEnumDescriptor(_VARIABLEAGGREGATION)
VariableAggregation = enum_type_wrapper.EnumTypeWrapper(_VARIABLEAGGREGATION)
VARIABLE_SYNCHRONIZATION_AUTO = 0
VARIABLE_SYNCHRONIZATION_NONE = 1
VARIABLE_SYNCHRONIZATION_ON_WRITE = 2
VARIABLE_SYNCHRONIZATION_ON_READ = 3
VARIABLE_AGGREGATION_NONE = 0
VARIABLE_AGGREGATION_SUM = 1
VARIABLE_AGGREGATION_MEAN = 2
VARIABLE_AGGREGATION_ONLY_FIRST_REPLICA = 3
_VARIABLEDEF = _descriptor.Descriptor(name='VariableDef', full_name='tensorflow.VariableDef', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='variable_name', full_name='tensorflow.VariableDef.variable_name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='initial_value_name', full_name='tensorflow.VariableDef.initial_value_name', index=1, number=6, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='initializer_name', full_name='tensorflow.VariableDef.initializer_name', index=2, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='snapshot_name', full_name='tensorflow.VariableDef.snapshot_name', index=3, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='save_slice_info_def', full_name='tensorflow.VariableDef.save_slice_info_def', index=4, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_resource', full_name='tensorflow.VariableDef.is_resource', index=5, number=5, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='trainable', full_name='tensorflow.VariableDef.trainable', index=6, number=7, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='synchronization', full_name='tensorflow.VariableDef.synchronization', index=7, number=8, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='aggregation', full_name='tensorflow.VariableDef.aggregation', index=8, number=9, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=57, serialized_end=385)
_SAVESLICEINFODEF = _descriptor.Descriptor(name='SaveSliceInfoDef', full_name='tensorflow.SaveSliceInfoDef', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='full_name', full_name='tensorflow.SaveSliceInfoDef.full_name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='full_shape', full_name='tensorflow.SaveSliceInfoDef.full_shape', index=1, number=2, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='var_offset', full_name='tensorflow.SaveSliceInfoDef.var_offset', index=2, number=3, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='var_shape', full_name='tensorflow.SaveSliceInfoDef.var_shape', index=3, number=4, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=387, serialized_end=483)
_VARIABLEDEF.fields_by_name['save_slice_info_def'].message_type = _SAVESLICEINFODEF
_VARIABLEDEF.fields_by_name['synchronization'].enum_type = _VARIABLESYNCHRONIZATION
_VARIABLEDEF.fields_by_name['aggregation'].enum_type = _VARIABLEAGGREGATION
DESCRIPTOR.message_types_by_name['VariableDef'] = _VARIABLEDEF
DESCRIPTOR.message_types_by_name['SaveSliceInfoDef'] = _SAVESLICEINFODEF
DESCRIPTOR.enum_types_by_name['VariableSynchronization'] = _VARIABLESYNCHRONIZATION
DESCRIPTOR.enum_types_by_name['VariableAggregation'] = _VARIABLEAGGREGATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
VariableDef = _reflection.GeneratedProtocolMessageType('VariableDef', (_message.Message,), {'DESCRIPTOR': _VARIABLEDEF, '__module__': 'tensorflow.core.framework.variable_pb2'})
_sym_db.RegisterMessage(VariableDef)
SaveSliceInfoDef = _reflection.GeneratedProtocolMessageType('SaveSliceInfoDef', (_message.Message,), {'DESCRIPTOR': _SAVESLICEINFODEF, '__module__': 'tensorflow.core.framework.variable_pb2'})
_sym_db.RegisterMessage(SaveSliceInfoDef)
DESCRIPTOR._options = None
